# icutils
<div align="center">
  <img src="ignitarium-logo.png">
</div>

[![PyPI version](https://badge.fury.io/py/trial-IGNchinmay.svg)](https://badge.fury.io/py/trial-IGNchinmay)

A sample test package for CV